@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for GNU Prolog 1.4.2 (and later versions)
-%  Last updated on February 16, 2015
+%  Last updated on May 13, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -109,10 +109,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-% setup_call_cleanup(+callable, +callable, +callable)
-
-setup_call_cleanup(_, _, _) :-
-	throw(not_supported(setup_call_cleanup/3)).
+% setup_call_cleanup(+callable, +callable, +callable) -- not supported
 
 
 
@@ -203,8 +200,8 @@ setup_call_cleanup(_, _, _) :-
 '$lgt_prolog_feature'(prolog_compatible_version, @>=((1,4,2))).
 '$lgt_prolog_feature'(prolog_conformance, Mode) :-
 	(	current_prolog_flag(strict_iso, on) ->
-		Mode = iso_strict
-	;	Mode = iso_lax
+		Mode = strict
+	;	Mode = lax
 	).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
