@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for Lean Prolog 3.8.8 and later versions
-%  Last updated on May 13, 2015
+%  Last updated on July 4, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -158,6 +158,9 @@ format(Format, Arguments) :-
 
 % setup_call_cleanup(+callable, +callable, +callable) -- not supported
 
+setup_call_cleanup(_, _, _) :-
+	throw(not_supported(setup_call_cleanup/3)).
+
 
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -566,7 +569,8 @@ to_engine(Interactor, Pattern, Goal) :-
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
 '$lgt_read_term'(Stream, Term, [singletons([])], LineBegin-LineEnd, Variables) :-
-	read_term(Stream, yes, Term, Variables, LineBegin, LineEnd).
+	read_term(Stream, yes, Term, Variables, LineBegin0, LineEnd),
+	LineBegin is LineBegin0 + 1.
 
 
 
